summaryrefslogtreecommitdiffstats
path: root/ksysv/ksvconfigwizard.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'ksysv/ksvconfigwizard.cpp')
-rw-r--r--ksysv/ksvconfigwizard.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/ksysv/ksvconfigwizard.cpp b/ksysv/ksvconfigwizard.cpp
index a70ea7d..a869d46 100644
--- a/ksysv/ksvconfigwizard.cpp
+++ b/ksysv/ksvconfigwizard.cpp
@@ -33,14 +33,14 @@
#include <tqpushbutton.h>
/*
* Constructs a KSVConfigWizard which is a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'
*
* The wizard will by default be modeless, unless you set 'modal' to
* TRUE to construct a modal wizard.
*/
-KSVConfigWizard::KSVConfigWizard (TQWidget* tqparent, const char* name, bool modal, WFlags fl)
- : ConfigWizard (tqparent, name, modal, fl),
+KSVConfigWizard::KSVConfigWizard (TQWidget* parent, const char* name, bool modal, WFlags fl)
+ : ConfigWizard (parent, name, modal, fl),
mChosenDistribution (Debian)
{
mDistributionBoxLayout->setSpacing (KDialog::spacingHint());
@@ -33,14 +33,14 @@
#include <tqpushbutton.h>
/*
- * Constructs a KSVConfigWizard which is a child of 'tqparent', with the
+ * Constructs a KSVConfigWizard which is a child of 'parent', with the
* name 'name' and widget flags set to 'f'
*